<?php

class Selected_items {

	var $settings		= array();
	
	var $name			= 'Selected Items';
	var $version		= '1.3';
	var $description	= 'Select arbitrarily ordered lists of entries';
	var $settings_exist	= 'n';
	var $docs_url		= 'http://www.brandnewbox.co.uk/docs/';
	
	// Constructor
	function Selected_items($settings='')
	{
		$this->settings = $settings;
	}
	
	// Activate extension
	function activate_extension ()
	{
		global $DB;
		
		$DB->query(
			$DB->insert_string('exp_extensions',
				array(
						'extension_id' => '',
						'class'        => get_class($this),
						'method'       => "reorder_entries",
						'hook'         => "weblog_entries_tagdata_end",
						'settings'     => '',
						'priority'     => 10,
						'version'      => $this->version,
						'enabled'      => 'y'
				)
			)
		);
				
	}
	    
    // Update extension
    function update_extension($current = '')
    {
        global $DB;
        
        if ($current == '' OR $current == $this->version)
        {
            return FALSE;
        }
        
        $DB->query("UPDATE exp_extensions SET version = '".$DB->escape_str($this->version)."' WHERE class = '".get_class($this)."'");
    }

    // Disable extension
    function disable_extension()
    {
        global $DB;
        
        $DB->query("DELETE FROM exp_extensions WHERE class = '".get_class($this)."'");
    }

	function settings()
	{
		$settings = array();
		
		// Complex:
		// [variable_name] => array(type, values, default value)
		// variable_name => short name for setting and used as the key for language file variable
		// type:  t - textarea, r - radio buttons, s - select, ms - multiselect, f - function calls
		// values:  can be array (r, s, ms), string (t), function name (f)
		// default:  name of array member, string, nothing
		//
		// Simple:
		// [variable_name] => 'Butter'
		// Text input, with 'Butter' as the default.

		return $settings;
	}
	
	function reorder_entries( $tagdata, $row, $weblog ) {
        global $TMPL, $IN, $FNS, $tagdataArray;

				/* Get params from weblog tag */
				$params = $TMPL->tagparams;

				$pagination_tags = array( "title", "url_title", "entry_id" );
				
				/* If the orderby parameter is set correctly, reorder items */
				if ( isset( $params[ "orderby" ] ) 
					&& $params[ "orderby" ] == "selecteditems" ) {
						
					if ( isset( $params[ "entry_id" ] )) {
						$entry_id = $row[ "entry_id" ];
					} 
					$individual_entry_id = 0;
					if ( $IN->QSTR && is_numeric( $IN->QSTR ) ) {
						$individual_entry_id = $IN->QSTR;
					}
					
					/* Put tag data into global array */
					$tagdataArray[ $entry_id ][ "tagdata" ] = $tagdata;
					foreach ( $pagination_tags as $field ) {
						if ( isset( $row[ $field ] )) {
							$tagdataArray[ $entry_id ][ $field ] = $row[ $field ];
						}
					}
					
					/* If this is the last entry, stitch entries together in the
					   correct order and return */
					if ( $row[ "count" ] == $row[ "total_results" ] ) {

						$order = split( "\|", $params[ "entry_id" ] );
						$tagdata = "";
						$count=1;
						$loop=0;
						foreach ( $order as $key ) {
						
							$loop++;

							$prev = isset( $order[ $loop-2 ] ) ? $order[ $loop-2 ] : false;
							$next = isset( $order[ $loop ] ) ? $order[ $loop ] : false;
							
							$cond[ "selecteditems_prev" ] = ( $prev ? 'TRUE' : 'FALSE' );
							$cond[ "selecteditems_next" ] = ( $next ? 'TRUE' : 'FALSE' );

							if ( $individual_entry_id == 0 ) {
								$cond[ "selecteditems_prev" ] = 'FALSE';
								$cond[ "selecteditems_next" ] = 'FALSE';
							}

							$cond[ "selecteditems_count" ] = $count;

							if ( !isset($tagdataArray[ $key ]) ) { continue; }

							$tagdataArray[ $key ][ "tagdata" ] = $FNS->prep_conditionals($tagdataArray[ $key ][ "tagdata" ], $cond);
							
							if ( $individual_entry_id == 0 || $individual_entry_id == $key ) { 

							/* Parse tags */
							
							$thisTag = $tagdataArray[ $key ][ "tagdata" ];
							
							$thisTag = str_replace("{selecteditems_count}", $count++, $thisTag );

							if ( $individual_entry_id == $key ) {
								foreach ( $pagination_tags as $field ) {
									if ( $prev ) {
										$thisTag = str_replace("{selecteditems_prev_".$field."}", $tagdataArray[ $prev ][ $field ], $thisTag);
									}
									if ( $next ) {
										$thisTag = str_replace("{selecteditems_next_".$field."}", $tagdataArray[ $next ][ $field ], $thisTag);
									}
								}
							}

							foreach ( $pagination_tags as $field ) {
								$thisTag = str_replace("{selecteditems_prev_".$field."}", '', $thisTag);
								$thisTag = str_replace("{selecteditems_next_".$field."}", '', $thisTag);
							}
							
							if ( preg_match( "/" . LD . 'selecteditems_switch="(.*?)"' . RD . "/s", $TMPL->tagdata, $matches) ) {
							
							 	$opts = explode( "|", $matches[1] );                              
							 	$thisTag = str_replace($matches[0], $opts[ ($count - 2) % count( $opts ) ], $thisTag);
							 	
							}
	
							$tagdata .= $thisTag;
							
							}
						}
						
						unset( $tagdataArray );
						
					} else {
						/* If not the last entry, don't return anything yet */
						$tagdata = "";
					}
					
				}
				
	      return $tagdata;
    }
    
}

?>